
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.9.post2',
    'branch_nick': 'hotfix-source-mismatch',
    'revision_id': '7029258afd11db054e13917c45db8b1bba5385be',
    'revno': 10059
}
